@@ -122,7 +122,7 @@ weechat_guile_output_flush ()
     char *temp_buffer, *command;
     int length;
 
-    if (!*guile_buffer_output[0])
+    if (!(*guile_buffer_output)[0])
         return;
 
     /* if there's no buffer, we catch the output, so there's no flush */
@@ -285,7 +285,7 @@ weechat_guile_hashtable_to_alist (struct t_hashtable *hashtable)
 /*
  * Converts a guile alist to a WeeChat hashtable.
  *
- * Note: hashtable must be free after use.
+ * Note: hashtable must be freed after use.
  */
 
 struct t_hashtable *
