@@ -29,6 +29,7 @@
 #include "relay-buffer.h"
 #include "relay-client.h"
 #include "relay-config.h"
+#include "relay-remote.h"
 #include "relay-raw.h"
 
 
@@ -47,8 +48,8 @@ int relay_buffer_selected_line = 0;
 int
 relay_buffer_is_relay (struct t_gui_buffer *buffer)
 {
-    return ((relay_raw_buffer && (buffer == relay_raw_buffer))
-            || (relay_buffer && (buffer == relay_buffer))) ? 1 : 0;
+    return (weechat_buffer_get_pointer (buffer, "plugin") == weechat_relay_plugin) ?
+        1 : 0;
 }
 
 /*
@@ -77,11 +78,11 @@ relay_buffer_refresh (const char *hotlist)
                       weechat_color ("lightgreen"),
                       /* disconnect */
                       (client_selected
-                       && !RELAY_CLIENT_HAS_ENDED(client_selected)) ?
+                       && !RELAY_STATUS_HAS_ENDED(client_selected->status)) ?
                       _("  [D] Disconnect") : "",
                       /* remove */
                       (client_selected
-                       && RELAY_CLIENT_HAS_ENDED(client_selected)) ?
+                       && RELAY_STATUS_HAS_ENDED(client_selected->status)) ?
                       _("  [R] Remove") : "",
                       /* purge old */
                       _("  [P] Purge finished"),
@@ -98,7 +99,7 @@ relay_buffer_refresh (const char *hotlist)
                   weechat_config_string (relay_config_color_text_bg));
 
         snprintf (str_status, sizeof (str_status),
-                  "%s", _(relay_client_status_string[ptr_client->status]));
+                  "%s", _(relay_status_string[ptr_client->status]));
         length = weechat_utf8_strlen_screen (str_status);
         if (length < 20)
         {
@@ -153,10 +154,8 @@ relay_buffer_refresh (const char *hotlist)
                           str_date_start,
                           str_date_end);
 
-        if (str_recv)
-            free (str_recv);
-        if (str_sent)
-            free (str_sent);
+        free (str_recv);
+        free (str_sent);
 
         line++;
     }
@@ -174,6 +173,7 @@ relay_buffer_input_cb (const void *pointer, void *data,
                        const char *input_data)
 {
     struct t_relay_client *client, *ptr_client, *next_client;
+    const char *ptr_remote_name, *ptr_remote_id;
 
     /* make C compiler happy */
     (void) pointer;
@@ -191,7 +191,7 @@ relay_buffer_input_cb (const void *pointer, void *data,
         /* disconnect client */
         if (weechat_strcmp (input_data, "d") == 0)
         {
-            if (client && !RELAY_CLIENT_HAS_ENDED(client))
+            if (client && !RELAY_STATUS_HAS_ENDED(client->status))
             {
                 relay_client_disconnect (client);
                 relay_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
@@ -204,7 +204,7 @@ relay_buffer_input_cb (const void *pointer, void *data,
             while (ptr_client)
             {
                 next_client = ptr_client->next_client;
-                if (RELAY_CLIENT_HAS_ENDED(ptr_client))
+                if (RELAY_STATUS_HAS_ENDED(ptr_client->status))
                     relay_client_free (ptr_client);
                 ptr_client = next_client;
             }
@@ -218,13 +218,25 @@ relay_buffer_input_cb (const void *pointer, void *data,
         /* remove client */
         else if (weechat_strcmp (input_data, "r") == 0)
         {
-            if (client && RELAY_CLIENT_HAS_ENDED(client))
+            if (client && RELAY_STATUS_HAS_ENDED(client->status))
             {
                 relay_client_free (client);
                 relay_buffer_refresh (WEECHAT_HOTLIST_MESSAGE);
             }
         }
     }
+    else
+    {
+        ptr_remote_name = weechat_buffer_get_string (buffer,
+                                                     "localvar_relay_remote");
+        ptr_remote_id = weechat_buffer_get_string (buffer,
+                                                   "localvar_relay_remote_id");
+        if (ptr_remote_name && ptr_remote_name[0]
+            && ptr_remote_id && ptr_remote_id[0])
+        {
+            relay_remote_buffer_input (buffer, input_data);
+        }
+    }
 
     return WEECHAT_RC_OK;
 }
@@ -286,6 +298,5 @@ relay_buffer_open ()
         &relay_buffer_input_cb, NULL, NULL,
         &relay_buffer_close_cb, NULL, NULL);
 
-    if (buffer_props)
-        weechat_hashtable_free (buffer_props);
+    weechat_hashtable_free (buffer_props);
 }
